
# Slot: label



URI: [gocam:object__label](https://w3id.org/gocam/object__label)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [BiologicalProcessTermObject](BiologicalProcessTermObject.md)
 * [CellTypeTermObject](CellTypeTermObject.md)
 * [CellularAnatomicalEntityTermObject](CellularAnatomicalEntityTermObject.md)
 * [EvidenceTermObject](EvidenceTermObject.md)
 * [GeneProductTermObject](GeneProductTermObject.md)
 * [GrossAnatomicalStructureTermObject](GrossAnatomicalStructureTermObject.md)
 * [InformationBiomacromoleculeTermObject](InformationBiomacromoleculeTermObject.md)
 * [MolecularFunctionTermObject](MolecularFunctionTermObject.md)
 * [MoleculeTermObject](MoleculeTermObject.md)
 * [Object](Object.md)
 * [PhaseTermObject](PhaseTermObject.md)
 * [PredicateTermObject](PredicateTermObject.md)
 * [ProteinComplexTermObject](ProteinComplexTermObject.md)
 * [PublicationObject](PublicationObject.md)
 * [TaxonTermObject](TaxonTermObject.md)
 * [TermObject](TermObject.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | rdfs:label |
